|PyPI badge| |Installs badge| |License badge| |Wheel badge|

Description
-----------
Automatic admin users for Django projects.

|Screenshot|

License
-------

This project is open sourced under the `MIT License`_.

Installation
------------

.. code-block:: bash

    $ pip install django-autoadmin

* Add 'autoadmin' to your project's INSTALLED_APPS list.
* Load the **autoadmin_tags** in your login template.
* Call the **autoadmin_partial** to display the information of the autogenerated admin user.
* Use the management command **createautoadmin** to create an admin user with an automatic password.

Contribute
----------

- Check for open issues or open a fresh issue to start a discussion around a feature idea or a bug.
- Fork `the repository`_ on GitHub to start making your changes to the **master** branch (or branch off of it).
- Write a test which shows that the bug was fixed or that the feature works as expected.
- Make sure to add yourself to the `AUTHORS file`_.
- Send a pull request

.. _`MIT License`: https://github.com/rosarior/django-autoadmin/blob/master/AUTHORS.rst
.. _`the repository`: http://github.com/rosarior/django-autoadmin
.. _`AUTHORS file`: https://github.com/rosarior/django-autoadmin/blob/master/AUTHORS.rst
.. |Screenshot| image:: https://raw.githubusercontent.com/rosarior/django-autoadmin/master/Screenshot.png


.. |Installs badge| image:: http://img.shields.io/pypi/dm/django-autoadmin.svg?style=flat
   :target: https://crate.io/packages/django-autoadmin/
.. |PyPI badge| image:: http://img.shields.io/pypi/v/django-autoadmin.svg?style=flat
   :target: http://badge.fury.io/py/django-autoadmin
.. |Wheel badge| image:: http://img.shields.io/badge/wheel-yes-green.svg?style=flat
.. |License badge| image:: http://img.shields.io/badge/license-MIT-green.svg?style=flat
